<?php

namespace Litecms\Blog\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litecms\Blog\Interfaces\CategoryRepositoryInterface;
use Litecms\Blog\Repositories\Eloquent\Filters\CategoryPublicFilter;
use Litecms\Blog\Repositories\Eloquent\Presenters\CategoryListPresenter;

class CategoryPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        CategoryRepositoryInterface $category
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litecms.blog.modules'), 'category', guard_url('category'));
        $this->repository = $category;
    }

    /**
     * Show category's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(CategoryPublicFilter::class)
            ->setPresenter(CategoryListPresenter::class)
            ->select('categories.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('blog::category.names'))
            ->view('blog::public.category.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show category.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('blog::category.name'))
            ->view('blog::public.category.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
