<?php

namespace Litecms\Blog\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litecms\Blog\Interfaces\TagRepositoryInterface;
use Litecms\Blog\Repositories\Eloquent\Filters\TagPublicFilter;
use Litecms\Blog\Repositories\Eloquent\Presenters\TagListPresenter;

class TagPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        TagRepositoryInterface $tag
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litecms.blog.modules'), 'tag', guard_url('tag'));
        $this->repository = $tag;
    }

    /**
     * Show tag's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(TagPublicFilter::class)
            ->setPresenter(TagListPresenter::class)
            ->select('tags.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('blog::tag.names'))
            ->view('blog::public.tag.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show tag.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('blog::tag.name'))
            ->view('blog::public.tag.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
